==> certmanager-model-v1alpha2-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateConditionBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateConditionBuilder extends CertificateConditionFluentImpl<CertificateConditionBuilder> implements VisitableBuilder<CertificateCondition,CertificateConditionBuilder>{
  public CertificateConditionBuilder() {
    this(false);
  }
  public CertificateConditionBuilder(Boolean validationEnabled) {
    this(new CertificateCondition(), validationEnabled);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateCondition(), validationEnabled);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent,CertificateCondition instance) {
    this(fluent, instance, false);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent,CertificateCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CertificateConditionBuilder(CertificateCondition instance) {
    this(instance,false);
  }
  public CertificateConditionBuilder(CertificateCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  CertificateConditionFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateCondition build() {
    CertificateCondition buildable = new CertificateCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getObservedGeneration(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateConditionBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateConditionBuilder extends CertificateConditionFluent<CertificateConditionBuilder> implements VisitableBuilder<CertificateCondition,CertificateConditionBuilder>{
  public CertificateConditionBuilder() {
    this(false);
  }
  public CertificateConditionBuilder(Boolean validationEnabled) {
    this(new CertificateCondition(), validationEnabled);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateCondition(), validationEnabled);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent,CertificateCondition instance) {
    this(fluent, instance, false);
  }
  public CertificateConditionBuilder(CertificateConditionFluent<?> fluent,CertificateCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new CertificateCondition());

    if (instance != null) {
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CertificateConditionBuilder(CertificateCondition instance) {
    this(instance,false);
  }
  public CertificateConditionBuilder(CertificateCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new CertificateCondition());

    if (instance != null) {
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
    }
    this.validationEnabled = validationEnabled; 
  }
  CertificateConditionFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateCondition build() {
    CertificateCondition buildable = new CertificateCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getObservedGeneration(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  
}
